@@ -1,8 +1,8 @@
-__version__ = '1.7.15'
+__version__ = '1.8.2'
 
 import logging
 
-logging.basicConfig()
+#logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 from .interface import (Contract, ContractNotRespected,
